import React from 'react';
export interface ButtonProps {
    /** 按钮类型 */
    type: 'default' | 'primary' | 'link' | 'text' | 'warning' | 'danger' | 'ghost' | 'simple' | 'simple-primary';
    /** 按钮形状 */
    /** 将按钮宽度调整为其父宽度的选项 */
    block?: boolean;
    /** 大小 */
    size: 'xs' | 'sm' | 'md' | 'lg';
    /** 点击跳转的地址，指定此属性 button 的行为和 a 链接一致 */
    href: string;
    /**相当于 a 链接的 target 属性，href 存在时生效 */
    target?: string;
    /** 按钮内联样式 */
    style?: React.CSSProperties;
    /** 按钮额外class */
    className?: string;
    /** 按钮失效状态	 */
    disabled?: boolean;
    /** 根据pending变化 自动设置disabled状态	 */
    autoDisabled?: boolean;
    /** 按钮载入状态	 */
    loading?: boolean;
    /** 根据pending变化 自动设置loading状态 	 */
    autoLoading?: boolean;
    /** 点击事件触发模式 ( 实时、竟态锁、防抖、节流、自定义防抖首尾执行函数 ) */
    clickMode: 'realtime' | 'lock' | 'debounce' | 'throttle' | 'customDebounce';
    /** 点击按钮时的回调	 */
    onClick: () => void;
    /** 点击事件执行状态回调	 */
    onChange: (pending: boolean) => void;
    children?: () => void;
    /** 自定义防抖 首执行函数 当clickMode为customDebounce时生效	*/
    leadingFn: () => void;
    /** 自定义防抖 尾执行函数	当clickMode为customDebounce时生效 */
    trailingFn: () => void;
    /** 自定义防抖配置 */
    debounceOptions: {
        leading: boolean;
        trailing: boolean;
        wait?: number;
        maxWait?: number;
    };
    /** 自定义节流配置  */
    throttleOptions: {
        leading: boolean;
        trailing: boolean;
        wait?: number;
    };
}
